@@ -5,7 +5,6 @@ from functools import total_ordering
 import sys, math
 from math import ceil, log
 from collections import defaultdict, OrderedDict
-import attr
 
 # must match <linux/nl80211.h> enum nl80211_reg_rule_flags
 
@@ -32,21 +31,38 @@ dfs_regions = {
 
 @total_ordering
 
-@attr.s(frozen=True)
 class WmmRule(object):
-    vo_c = attr.ib()
-    vi_c = attr.ib()
-    be_c = attr.ib()
-    bk_c = attr.ib()
-    vo_ap = attr.ib()
-    vi_ap = attr.ib()
-    be_ap = attr.ib()
-    bk_ap = attr.ib()
+
+    def __init__(self, vo_c, vi_c, be_c, bk_c, vo_ap, vi_ap, be_ap, bk_ap):
+        self.vo_c = vo_c
+        self.vi_c = vi_c
+        self.be_c = be_c
+        self.bk_c = bk_c
+        self.vo_ap = vo_ap
+        self.vi_ap = vi_ap
+        self.be_ap = be_ap
+        self.bk_ap = bk_ap
 
     def _as_tuple(self):
         return (self.vo_c, self.vi_c, self.be_c, self.bk_c,
                 self.vo_ap, self.vi_ap, self.be_ap, self.bk_ap)
 
+    def __eq__(self, other):
+        if other is None:
+            return False
+        return (self._as_tuple() == other._as_tuple())
+
+    def __ne__(self, other):
+        return not (self == other)
+
+    def __lt__(self, other):
+        if other is None:
+            return False
+        return (self._as_tuple() < other._as_tuple())
+
+    def __hash__(self):
+        return hash(self._as_tuple())
+
 class FreqBand(object):
     def __init__(self, start, end, bw, comments=None):
         self.start = start
